import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:hub/components/templates_components/card_item_template_component/card_item_template_component_widget.dart';
import 'package:hub/initialization.dart';
import 'package:hub/main.dart' as app;
import 'package:hub/shared/helpers/storage/base_storage.dart';
import 'package:hub/shared/helpers/storage/storage_helper.dart';
import 'package:integration_test/integration_test.dart';

void main() {
  IntegrationTestWidgetsFlutterBinding.ensureInitialized();

  group('ProvisionalHistoryPage Integration Test', () {
    setUpAll(() async => await initializeApp().then((_) async {
          await StorageHelper().set(SecureStorageKey.isLogged.value, 'true');
          await StorageHelper().set(SecureStorageKey.haveLocal.value, 'true');
          await StorageHelper()
              .set(KeychainStorageKey.devUUID.value, 'b5c3818753e76d85');
          await StorageHelper().set(
              KeychainStorageKey.userUUID.value, '649c45d7514a28.85876308');
          await StorageHelper().set(KeychainStorageKey.clientUUID.value, '7');
        }));

    testWidgets('Filter Provisional History', (WidgetTester tester) async {
      app.main();
      await tester.pumpAndSettle();

      final Finder menuButton = find.byIcon(Icons.person_search_outlined);
      await tester.tap(menuButton);
      await tester.pumpAndSettle();

      final Finder filterButton = find.byIcon(Icons.filter_list);
      await tester.tap(filterButton);
      await tester.pumpAndSettle();

      final Finder activeFilterOption = find.text('Active');
      await tester.tap(activeFilterOption);
      await tester.pumpAndSettle();

      final Finder applyFilterButton = find.text('Apply');
      await tester.tap(applyFilterButton);
      await tester.pumpAndSettle();

      expect(find.byType(CardItemTemplateComponentWidget), findsWidgets);
    });
  });
}
