import 'package:flutter/material.dart';
import 'package:hub/backend/api_requests/api_manager.dart';
import 'package:hub/flutter_flow/flutter_flow_model.dart';
import 'package:hub/flutter_flow/request_manager.dart';
import 'package:hub/pages/message_history_page/message_history_page_widget.dart';
import 'package:hub/shared/helpers/storage/base_storage.dart';
import 'package:hub/shared/helpers/storage/storage_helper.dart';

class MessageHistoryPageModel
    extends FlutterFlowModel<MessageHistoryPageWidget> {
  late final String devUUID;
  late final String userUUID;
  late final String cliUUID;

  final unfocusNode = FocusNode();
  FocusNode? textFieldFocusNode;
  TextEditingController? textController;
  String? Function(BuildContext, String?)? textControllerValidator;

  TabController? tabBarController;
  int get tabBarCurrentIndex =>
      tabBarController != null ? tabBarController!.index : 0;

  final _getLiberationsManager = StreamRequestManager<ApiCallResponse>();
  Stream<ApiCallResponse> getLiberations({
    String? uniqueQueryKey,
    bool? overrideCache,
    required Stream<ApiCallResponse> Function() requestFn,
  }) =>
      _getLiberationsManager.performRequest(
        uniqueQueryKey: uniqueQueryKey,
        overrideCache: overrideCache,
        requestFn: requestFn,
      );
  void clearGetLiberationsCache() => _getLiberationsManager.clear();
  void clearGetLiberationsCacheKey(String? uniqueKey) =>
      _getLiberationsManager.clearRequest(uniqueKey);

  @override
  void initState(BuildContext context) {
    init();
  }

  Future<void> init() async {
    devUUID =
        (await StorageHelper().get(KeychainStorageKey.devUUID.value)) ?? '';
    userUUID =
        (await StorageHelper().get(KeychainStorageKey.userUUID.value)) ?? '';
    cliUUID =
        (await StorageHelper().get(KeychainStorageKey.clientUUID.value)) ?? '';
  }

  @override
  void dispose() {
    unfocusNode.dispose();
    textFieldFocusNode?.dispose();
    textController?.dispose();
    tabBarController?.dispose();

    clearGetLiberationsCache();
  }
}
