import 'dart:convert';
import 'dart:developer';

import 'package:hub/flutter_flow/custom_functions.dart';
import 'package:hub/main.dart';
import 'package:hub/shared/components/molecules/menu/data/data_sources/menu_local_data_source.dart';
import 'package:hub/shared/components/molecules/menu/domain/respositories/menu_repository.dart';
import 'package:hub/shared/components/molecules/menu/index.dart';
import 'package:hub/shared/components/molecules/modules/index.dart';
import 'package:hub/shared/extensions/string_extensions.dart';
import 'package:hub/shared/helpers/storage/base_storage.dart';
import 'package:hub/shared/helpers/storage/storage_helper.dart';

class MenuRepositoryImpl implements MenuRepository {
  final MenuLocalDataSource menuDataSource = MenuLocalDataSourceImpl();

  @override
  Future<List<MenuItem?>> generateMenuEntries(
      List<MenuEntry> menuEntries, EnumMenuItem item) async {
    List<MenuItem?> entries = [];
    // final bool isNewVersion = await StorageHelper().get(KeychainStorageKey.isNewVersion.value).then((v) => v.toBoolean());

    try {
      for (var entry in menuEntries) {
        final bool isDefault =
            await menuDataSource.processDisplayDefault(item, entry, entries);
        if (isDefault) continue;
        final licenseValue =
            await LicenseRepositoryImpl().getLicense(entry.key);
        if (licenseValue != null) {
          final licenseMap = await stringToMap(licenseValue);
          final display = EnumDisplay.fromString(licenseMap['display']);
          final startDate = licenseMap['startDate'] ?? '';
          final expirationDate = licenseMap['expirationDate'] ?? '';
          final isStarted =
              await menuDataSource.processStartDate(startDate, entry);
          final isExpired =
              await menuDataSource.processExpirationDate(expirationDate, entry);
          if (isStarted && !isExpired) {
            await menuDataSource.handleMenu(item, display, entry, entries);
          }
          if (isExpired) {
            log('Entry ${entry.key} is expired');
            await menuDataSource.handleMenu(
                item, EnumDisplay.inactive, entry, entries);
          }
          if (!isStarted) {
            log('Entry ${entry.key} is not started');
            await menuDataSource.handleMenu(
                item, EnumDisplay.inactive, entry, entries);
          }
        }
      }
    } catch (e, s) {
      log('Error generating menu entries: $e', stackTrace: s);
    }
    return entries;
  }

  Future<EnumDisplay> processDisplay(
      Map<String, dynamic> module, bool isNewVersion) async {
    if (await _shouldUpdateDisplay(module, isNewVersion)) {
      final displayValue =
          module['display'] == EnumDisplay.active ? 'VISIVEL' : 'INVISIVEL';
      await LicenseLocalDataSourceImpl()
          .setDisplayByKey(['FRE-HUB-ABOUT-PROPERTY'], displayValue);
      return EnumDisplay.fromString(displayValue);
    }

    return EnumDisplay.fromString(module['display']);
  }

  Future<bool> _shouldUpdateDisplay(
      Map<String, dynamic> module, bool isNewVersion) async {
    const keysToCheck = [
      LicenseKeys.residents,
      LicenseKeys.vehicles,
      LicenseKeys.openedVisits
    ];
    return isNewVersion && keysToCheck.any((key) => module['key'] == key.value);
  }
}
